netneurotools: Tools for network neuroscience
=============================================

This toolbox is a collection of functions written in Python that get frequent
usage in the `Network Neuroscience Lab <netneurolab.github.io/>`_, housed in
the `Brain Imaging Centre <https://www.mcgill.ca/bic/home>`_ at
`McGill University <https://www.mcgill.ca/>`_.

.. image:: https://travis-ci.org/netneurolab/netneurotools.svg?branch=master
   :target: https://travis-ci.org/netneurolab/netneurotools
.. image:: https://codecov.io/gh/netneurolab/netneurotools/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/netneurolab/netneurotools
.. image:: https://readthedocs.org/projects/netneurotools/badge/?version=latest
   :target: https://netneurotools.readthedocs.io/en/latest
.. image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg
   :target: https://opensource.org/licenses/BSD-3-Clause

.. _usage:

Usage
-----

Check out our `documentation <https://netneurotools.readthedocs.io/en/latest>`_
for information on how to install and use ``netneurotools``!

.. _development:

Development
-----------

This package has been developed by members of the Network Neuroscience Lab in
pursuit of their research. While we've made every effort to ensure these tools
work and have some documentation, there is always room for improvement! If
you've found a bug, are experiencing a problem, or have a question, create a
new `issue <https://github.com/netneurolab/netneurotools/issues>`_ with some
information about it and one of our team members will do our best to help you.

.. _licensing:

License Information
-------------------

This codebase is licensed under the 3-clause BSD license. The full license can
be found in the `LICENSE <https://github.com/netneurolab/netneurotools/blob/
master/LICENSE>`_ file in the ``netneurotools`` distribution.

All trademarks referenced herein are property of their respective holders.

.. |sparkles| replace:: ✨
